@@ -404,6 +404,8 @@ class WebRemotePlugin(GObject.Object, Peas.Activatable):
 			return "image/png"
 		elif data[0:5] == b'<?xml':
 			return "image/svg+xml"
+		elif data[0:4] == b'<svg':
+			return "image/svg+xml"
 		else:
 			return "image/jpeg"
 
@@ -534,6 +536,10 @@ class WebRemotePlugin(GObject.Object, Peas.Activatable):
 		shell = self.object
 		self.db = shell.props.db
 
+		self.artcache = os.path.join(RB.user_cache_dir(), "album-art", "")
+		self.art_store = RB.ExtDB(name="album-art")
+		self.art_store.connect("added", self.art_added_cb)
+
 		self.shell_player = shell.props.shell_player
 		self.shell_player.connect("playing-song-changed", self.playing_song_changed_cb)
 		self.shell_player.connect("playing-song-property-changed", self.playing_song_property_changed_cb)
@@ -551,11 +557,6 @@ class WebRemotePlugin(GObject.Object, Peas.Activatable):
 		self.http_server.add_handler(path="/", callback=self.http_root_cb)
 
 		self.http_listen()
-		self.http_server.run_async()
-
-		self.artcache = os.path.join(RB.user_cache_dir(), "album-art", "")
-		self.art_store = RB.ExtDB(name="album-art")
-		self.art_store.connect("added", self.art_added_cb)
 
 
 	def do_deactivate(self):
